import { Driver } from "../driver/Driver";
import { ConnectionOptions } from "./ConnectionOptions";
import { Repository } from "../repository/Repository";
import { EventSubscriberInterface } from "../subscriber/EventSubscriberInterface";
import { EntityMetadata } from "../metadata-builder/metadata/EntityMetadata";
import { ConstructorFunction } from "../common/ConstructorFunction";
import { EntityListenerMetadata } from "../metadata-builder/metadata/EntityListenerMetadata";
import { EntityManager } from "../repository/EntityManager";
/**
 * A single connection instance to the database. Each connection has its own repositories, subscribers and metadatas.
 */
export declare class Connection {
    private _name;
    private _driver;
    private _entityMetadatas;
    private _entityListenerMetadatas;
    private _subscribers;
    private repositoryAndMetadatas;
    private _options;
    private entityManager;
    constructor(name: string, driver: Driver, options: ConnectionOptions);
    /**
     * The name of the connection.
     */
    name: string;
    /**
     * Database driver used by this connection.
     */
    driver: Driver;
    /**
     * All subscribers that are registered for this connection.
     */
    subscribers: EventSubscriberInterface<any>[];
    /**
     * All entity metadatas that are registered for this connection.
     */
    entityMetadatas: EntityMetadata[];
    /**
     * All entity listener metadatas that are registered for this connection.
     */
    entityListeners: EntityListenerMetadata[];
    /**
     * All repositories that are registered for this connection.
     */
    repositories: Repository<any>[];
    /**
     * This connection options and settings.
     */
    options: ConnectionOptions;
    /**
     * Performs connection to the database.
     */
    connect(): Promise<void>;
    /**
     * Closes this connection.
     */
    close(): Promise<void>;
    /**
     * Gets EntityManager of this connection.
     */
    getEntityManager(): EntityManager;
    /**
     * Gets repository for the given entity class.
     */
    getRepository<Entity>(entityClass: ConstructorFunction<Entity> | Function): Repository<Entity>;
    /**
     * Gets the entity metadata for the given entity class.
     */
    getEntityMetadata(entityClass: Function): EntityMetadata;
    /**
     * Registers entity metadatas for the current connection.
     */
    addEntityMetadatas(metadatas: EntityMetadata[]): Connection;
    /**
     * Registers entity listener metadatas for the current connection.
     */
    addEntityListenerMetadatas(metadatas: EntityListenerMetadata[]): Connection;
    /**
     * Registers subscribers for the current connection.
     */
    addSubscribers(subscribers: EventSubscriberInterface<any>[]): Connection;
    private createRepoMeta(metadata);
}
