import { Connection } from "./Connection";
import { Driver } from "../driver/Driver";
import { ConnectionOptions } from "tls";
import { NamingStrategy } from "../naming-strategy/NamingStrategy";
/**
 * Connection manager holds all connections made to the databases and providers helper management functions
 * for all exist connections.
 */
export declare class ConnectionManager {
    private connections;
    private _entityMetadataBuilder;
    private _namingStrategy;
    private _container;
    /**
     * Sets a container that can be used in custom user subscribers. This allows to inject services in subscribers.
     */
    container: {
        get(someClass: Function): any;
    };
    /**
     * Sets the naming strategy to be used instead of DefaultNamingStrategy.
     */
    namingStrategy: NamingStrategy;
    /**
     * Creates and adds a new connection with given driver.
     */
    createConnection(driver: Driver, options: ConnectionOptions): Connection;
    createConnection(name: string, driver: Driver, options: ConnectionOptions): Connection;
    /**
     * Gets registered connection with the given name. If connection name is not given then it will get a default
     * connection.
     */
    getConnection(name?: string): Connection;
    /**
     * Imports entities from the given paths (directories) for the given connection. If connection name is not given
     * then default connection is used.
     */
    importEntitiesFromDirectories(paths: string[]): void;
    importEntitiesFromDirectories(connectionName: string, paths: string[]): void;
    /**
     * Imports subscribers from the given paths (directories) for the given connection. If connection name is not given
     * then default connection is used.
     */
    importSubscribersFromDirectories(paths: string[]): void;
    importSubscribersFromDirectories(connectionName: string, paths: string[]): void;
    /**
     * Imports entities for the given connection. If connection name is not given then default connection is used.
     */
    importEntities(entities: Function[]): void;
    importEntities(connectionName: string, entities: Function[]): void;
    /**
     * Imports entities for the given connection. If connection name is not given then default connection is used.
     */
    importSubscribers(subscriberClasses: Function[]): void;
    importSubscribers(connectionName: string, subscriberClasses: Function[]): void;
    /**
     * We need to lazily initialize EntityMetadataBuilder because naming strategy can be set before we use entityMetadataBuilder.
     */
    private entityMetadataBuilder;
    /**
     * Creates a new instance of the given constructor.
     */
    private createContainerInstance(constructor);
}
