"use strict";
var ColumnTypes_1 = require("../../metadata-builder/types/ColumnTypes");
var MetadataStorage_1 = require("../../metadata-builder/MetadataStorage");
var ColumnMetadata_1 = require("../../metadata-builder/metadata/ColumnMetadata");
require("reflect-metadata");
/**
 * This column will store a creation date of the inserted object. Creation date is generated and inserted only once,
 * at the first time when you create an object, the value is inserted into the table, and is never touched again.
 */
function CreateDateColumn(options) {
    return function (object, propertyName) {
        var reflectedType = ColumnTypes_1.ColumnTypes.typeToString(Reflect.getMetadata("design:type", object, propertyName));
        // if column options are not given then create a new empty options
        if (!options)
            options = {};
        // implicitly set a type, because this column's type cannot be anything else except date
        options.type = ColumnTypes_1.ColumnTypes.DATETIME;
        // create and register a new column metadata
        MetadataStorage_1.defaultMetadataStorage.addColumnMetadata(new ColumnMetadata_1.ColumnMetadata({
            target: object.constructor,
            propertyName: propertyName,
            propertyType: reflectedType,
            isCreateDate: true,
            options: options
        }));
    };
}
exports.CreateDateColumn = CreateDateColumn;
//# sourceMappingURL=CreateDateColumn.js.map