import { Driver } from "./Driver";
import { SchemaBuilder } from "../schema-builder/SchemaBuilder";
import { QueryBuilder } from "../query-builder/QueryBuilder";
import { Connection } from "../connection/Connection";
import { BaseDriver } from "./BaseDriver";
import { ColumnMetadata } from "../metadata-builder/metadata/ColumnMetadata";
/**
 * This driver organizes work with mysql database.
 */
export declare class MysqlDriver extends BaseDriver implements Driver {
    /**
     * Connection used in this driver.
     */
    connection: Connection;
    /**
     * Mysql library.
     */
    private mysql;
    /**
     * Connection to mysql database.
     */
    private mysqlConnection;
    /**
     * Access to the native implementation of the database.
     */
    native: any;
    /**
     * Access to the native implementation of the database.
     */
    nativeConnection: any;
    /**
     * Database name to which this connection is made.
     */
    db: string;
    constructor(mysql?: any);
    /**
     * Creates a query builder which can be used to build an sql queries.
     */
    createQueryBuilder<Entity>(): QueryBuilder<Entity>;
    /**
     * Creates a schema builder which can be used to build database/table schemas.
     */
    createSchemaBuilder(): SchemaBuilder;
    /**
     * Performs connection to the database based on given connection options.
     */
    connect(): Promise<void>;
    /**
     * Closes connection with database.
     */
    disconnect(): Promise<void>;
    /**
     * Executes a given SQL query.
     */
    query<T>(query: string): Promise<T>;
    /**
     * Clears all tables in the currently connected database.
     */
    clearDatabase(): Promise<void>;
    /**
     * Updates rows that match given conditions in the given table.
     */
    update(tableName: string, valuesMap: Object, conditions: Object): Promise<void>;
    /**
     * Insert a new row into given table.
     */
    insert(tableName: string, keyValues: Object): Promise<any>;
    /**
     * Deletes from the given table by a given conditions.
     */
    delete(tableName: string, conditions: Object): Promise<void>;
    /**
     * Starts mysql transaction.
     */
    beginTransaction(): Promise<void>;
    /**
     * Ends mysql transaction.
     */
    endTransaction(): Promise<void>;
    /**
     * Prepares given value to a value to be persisted, based on its column type and metadata.
     */
    preparePersistentValue(value: any, column: ColumnMetadata): any;
    /**
     * Prepares given value to a value to be persisted, based on its column type and metadata.
     */
    prepareHydratedValue(value: any, column: ColumnMetadata): any;
    /**
     * Escapes given value.
     */
    escape(value: any): any;
}
