import { TableMetadata } from "./metadata/TableMetadata";
import { RelationMetadata } from "./metadata/RelationMetadata";
import { IndexMetadata } from "./metadata/IndexMetadata";
import { CompoundIndexMetadata } from "./metadata/CompoundIndexMetadata";
import { ColumnMetadata } from "./metadata/ColumnMetadata";
import { EventSubscriberMetadata } from "./metadata/EventSubscriberMetadata";
import { EntityListenerMetadata } from "./metadata/EntityListenerMetadata";
/**
 * Storage all metadatas of all available types: tables, fields, subscribers, relations, etc.
 * Each metadata represents some specifications of what it represents.
 */
export declare class MetadataStorage {
    private _tableMetadatas;
    private _eventSubscriberMetadatas;
    private _columnMetadatas;
    private _indexMetadatas;
    private _entityListenerMetadatas;
    private _compoundIndexMetadatas;
    private _relationMetadatas;
    tableMetadatas: TableMetadata[];
    eventSubscriberMetadatas: EventSubscriberMetadata[];
    columnMetadatas: ColumnMetadata[];
    indexMetadatas: IndexMetadata[];
    entityListenerMetadatas: EntityListenerMetadata[];
    compoundIndexMetadatas: CompoundIndexMetadata[];
    relationMetadatas: RelationMetadata[];
    addTableMetadata(metadata: TableMetadata): void;
    addRelationMetadata(metadata: RelationMetadata): void;
    addColumnMetadata(metadata: ColumnMetadata): void;
    addEventSubscriberMetadata(metadata: EventSubscriberMetadata): void;
    addIndexMetadata(metadata: IndexMetadata): void;
    addCompoundIndexMetadata(metadata: CompoundIndexMetadata): void;
    addEntityListenerMetadata(metadata: EntityListenerMetadata): void;
    findEventSubscribersForClasses(classes: Function[]): EventSubscriberMetadata[];
    findEntityListenersForClasses(classes: Function[]): EntityListenerMetadata[];
    findTableMetadatasForClasses(classes: Function[]): TableMetadata[];
    findCompoundIndexMetadatasForClasses(classes: Function[]): CompoundIndexMetadata[];
    findAbstractTableMetadatasForClasses(classes: Function[]): TableMetadata[];
    findIndexMetadatasForClasses(classes: Function[]): IndexMetadata[];
    findFieldMetadatasForClasses(classes: Function[]): ColumnMetadata[];
    findRelationMetadatasForClasses(classes: Function[]): RelationMetadata[];
    private hasTableMetadataWithObjectConstructor(constructor);
    private hasCompoundIndexMetadataWithObjectConstructor(constructor);
    private hasEventSubscriberWithObjectConstructor(constructor);
    private hasFieldMetadataOnProperty(constructor, propertyName);
    private hasRelationWithOneMetadataOnProperty(constructor, propertyName);
    private hasTableMetadataWithName(name);
    private hasFieldMetadataWithName(constructor, name);
    private hasRelationWithOneMetadataWithName(constructor, name);
}
/**
 * Default metadata storage used as singleton and can be used to storage all metadatas in the system.
 */
export declare const defaultMetadataStorage: MetadataStorage;
