"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var PropertyMetadata_1 = require("./PropertyMetadata");
/**
 * This metadata contains all information about class's column.
 */
var ColumnMetadata = (function (_super) {
    __extends(ColumnMetadata, _super);
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    function ColumnMetadata(args) {
        _super.call(this, args.target, args.propertyName);
        /**
         * Maximum length in the database.
         */
        this._length = "";
        /**
         * Indicates if this column is primary key.
         */
        this._isPrimary = false;
        /**
         * Indicates if this column is auto increment.
         */
        this._isAutoIncrement = false;
        /**
         * Indicates if value should be unique or not.
         */
        this._isUnique = false;
        /**
         * Indicates if can contain nulls or not.
         */
        this._isNullable = false;
        /**
         * Indicates if column will contain a created date or not.
         */
        this._isCreateDate = false;
        /**
         * Indicates if column will contain an updated date or not.
         */
        this._isUpdateDate = false;
        /**
         * Indicates if column will contain an updated date or not.
         */
        this._isVirtual = false;
        /**
         * Extra sql definition for the given column.
         */
        this._columnDefinition = "";
        /**
         * Column comment.
         */
        this._comment = "";
        if (args.isPrimaryKey)
            this._isPrimary = args.isPrimaryKey;
        if (args.isCreateDate)
            this._isCreateDate = args.isCreateDate;
        if (args.isUpdateDate)
            this._isUpdateDate = args.isUpdateDate;
        if (args.isVirtual)
            this._isVirtual = args.isVirtual;
        if (args.propertyType)
            this._propertyType = args.propertyType;
        if (args.options.name)
            this._name = args.options.name;
        if (args.options.type)
            this._type = args.options.type;
        if (args.options.length)
            this._length = args.options.length;
        if (args.options.autoIncrement)
            this._isAutoIncrement = args.options.autoIncrement;
        if (args.options.unique)
            this._isUnique = args.options.unique;
        if (args.options.nullable)
            this._isNullable = args.options.nullable;
        if (args.options.columnDefinition)
            this._columnDefinition = args.options.columnDefinition;
        if (args.options.comment)
            this._comment = args.options.comment;
        if (args.options.oldColumnName)
            this._oldColumnName = args.options.oldColumnName;
        if (args.options.scale)
            this._scale = args.options.scale;
        if (args.options.precision)
            this._precision = args.options.precision;
        if (args.options.collation)
            this._collation = args.options.collation;
    }
    Object.defineProperty(ColumnMetadata.prototype, "name", {
        // ---------------------------------------------------------------------
        // Accessors
        // ---------------------------------------------------------------------
        /**
         * Column name in the database.
         */
        get: function () {
            if (this._name)
                return this._name;
            return this.namingStrategy ? this.namingStrategy.columnName(this.propertyName) : this.propertyName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "propertyType", {
        /**
         * The real reflected property type.
         */
        get: function () {
            return this._propertyType.toLowerCase();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "type", {
        /**
         * Type of the column.
         */
        get: function () {
            return this._type;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "length", {
        /**
         * Column type's length. For example type = "string" and length = 100 means that ORM will create a column with
         * type varchar(100).
         */
        get: function () {
            return this._length;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isPrimary", {
        /**
         * Indicates if this column is a primary key.
         */
        get: function () {
            return this._isPrimary;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isAutoIncrement", {
        /**
         * Indicates if this column's value is auto incremented.
         */
        get: function () {
            return this._isAutoIncrement;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isUnique", {
        /**
         * Indicates if this column has unique key.
         */
        get: function () {
            return this._isUnique;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isNullable", {
        /**
         * Indicates if this column can have a NULL value.
         */
        get: function () {
            return this._isNullable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isCreateDate", {
        /**
         * Indicates if this column is special and contains object create date.
         */
        get: function () {
            return this._isCreateDate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isUpdateDate", {
        /**
         * Indicates if this column is special and contains object last update date.
         */
        get: function () {
            return this._isUpdateDate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isVirtual", {
        /**
         * Indicates if this column is virtual. Virtual column mean that it does not really exist in class. Virtual columns
         * are used for many-to-many tables.
         */
        get: function () {
            return this._isVirtual;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "columnDefinition", {
        /**
         * Extra column definition value.
         */
        get: function () {
            return this._columnDefinition;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "comment", {
        /**
         * Extra column's comment.
         */
        get: function () {
            return this._comment;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "oldColumnName", {
        /**
         * Column name used previously for this column. Used to make safe schema updates. Experimental and most probably
         * will be removed in the future. Avoid using it.
         */
        get: function () {
            return this._oldColumnName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "precision", {
        /**
         * The precision for a decimal (exact numeric) column (applies only for decimal column), which is the maximum
         * number of digits that are stored for the values.
         */
        get: function () {
            return this._precision;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "scale", {
        /**
         * The scale for a decimal (exact numeric) column (applies only for decimal column), which represents the number
         * of digits to the right of the decimal point and must not be greater than precision.
         */
        get: function () {
            return this._scale;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "collation", {
        /**
         * Column collation. Note that not all databases support it.
         */
        get: function () {
            return this._collation;
        },
        enumerable: true,
        configurable: true
    });
    return ColumnMetadata;
}(PropertyMetadata_1.PropertyMetadata));
exports.ColumnMetadata = ColumnMetadata;
//# sourceMappingURL=ColumnMetadata.js.map