import { ColumnMetadata } from "./ColumnMetadata";
import { TableMetadata } from "./TableMetadata";
export declare type OnDeleteType = "RESTRICT" | "CASCADE" | "SET NULL";
/**
 * This metadata interface contains all information foreign keys.
 */
export declare class ForeignKeyMetadata {
    /**
     * Table to which this foreign key is applied.
     */
    private _table;
    /**
     * Array of columns.
     */
    private _columns;
    /**
     * Table to which this foreign key is references.
     */
    private _referencedTable;
    /**
     * Array of referenced columns.
     */
    private _referencedColumns;
    /**
     * What to do with a relation on deletion of the row containing a foreign key.
     */
    private _onDelete;
    constructor(table: TableMetadata, columns: ColumnMetadata[], referencedTable: TableMetadata, referencedColumns: ColumnMetadata[], onDelete?: OnDeleteType);
    /**
     * Table to which this foreign key is applied.
     */
    table: TableMetadata;
    /**
     * Array of columns.
     */
    columns: ColumnMetadata[];
    /**
     * Table to which this foreign key is references.
     */
    referencedTable: TableMetadata;
    /**
     * Array of referenced columns.
     */
    referencedColumns: ColumnMetadata[];
    /**
     * Array of column names.
     */
    columnNames: string[];
    /**
     * Array of referenced column names.
     */
    referencedColumnNames: string[];
    /**
     * Foreign key name.
     */
    name: string;
    /**
     * Array of referenced column names.
     */
    onDelete: OnDeleteType;
}
