"use strict";
/**
 * This metadata interface contains all information foreign keys.
 */
var ForeignKeyMetadata = (function () {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    function ForeignKeyMetadata(table, columns, referencedTable, referencedColumns, onDelete) {
        this._table = table;
        this._columns = columns;
        this._referencedTable = referencedTable;
        this._referencedColumns = referencedColumns;
        this._onDelete = onDelete;
    }
    Object.defineProperty(ForeignKeyMetadata.prototype, "table", {
        // -------------------------------------------------------------------------
        // Accessors
        // -------------------------------------------------------------------------
        /**
         * Table to which this foreign key is applied.
         */
        get: function () {
            return this._table;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "columns", {
        /**
         * Array of columns.
         */
        get: function () {
            return this._columns;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "referencedTable", {
        /**
         * Table to which this foreign key is references.
         */
        get: function () {
            return this._referencedTable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "referencedColumns", {
        /**
         * Array of referenced columns.
         */
        get: function () {
            return this._referencedColumns;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "columnNames", {
        /**
         * Array of column names.
         */
        get: function () {
            return this.columns.map(function (column) { return column.name; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "referencedColumnNames", {
        /**
         * Array of referenced column names.
         */
        get: function () {
            return this.referencedColumns.map(function (column) { return column.name; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "name", {
        /**
         * Foreign key name.
         */
        get: function () {
            var key = (this.table.name + "_" + this.columnNames.join("_")) +
                ("_" + this.referencedTable.name + "_" + this.referencedColumnNames.join("_"));
            return "fk_" + require("sha1")(key); // todo: use crypto instead?
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "onDelete", {
        /**
         * Array of referenced column names.
         */
        get: function () {
            return this._onDelete;
        },
        enumerable: true,
        configurable: true
    });
    return ForeignKeyMetadata;
}());
exports.ForeignKeyMetadata = ForeignKeyMetadata;
//# sourceMappingURL=ForeignKeyMetadata.js.map