"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var PropertyMetadata_1 = require("./PropertyMetadata");
var RelationTypes_1 = require("../types/RelationTypes");
/**
 * This metadata interface contains all information about some document's relation.
 */
var RelationMetadata = (function (_super) {
    __extends(RelationMetadata, _super);
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    function RelationMetadata(args) {
        _super.call(this, args.target, args.propertyName);
        /**
         * Indicates if relation column value can be nullable or not.
         */
        this._isNullable = true;
        this._relationType = args.relationType;
        this._type = args.type;
        this._isOwning = args.isOwning;
        this._inverseSideProperty = args.inverseSideProperty;
        if (args.options.name)
            this._name = args.options.name;
        if (args.options.cascadeInsert)
            this._isCascadeInsert = args.options.cascadeInsert;
        if (args.options.cascadeUpdate)
            this._isCascadeUpdate = args.options.cascadeUpdate;
        if (args.options.cascadeRemove)
            this._isCascadeRemove = args.options.cascadeRemove;
        if (args.options.oldColumnName)
            this._oldColumnName = args.options.oldColumnName;
        if (args.options.nullable)
            this._isNullable = args.options.nullable;
        if (args.options.onDelete)
            this._onDelete = args.options.onDelete;
        if (!this._name)
            this._name = args.propertyName;
    }
    Object.defineProperty(RelationMetadata.prototype, "name", {
        // ---------------------------------------------------------------------
        // Accessors
        // ---------------------------------------------------------------------
        get: function () {
            return this.namingStrategy ? this.namingStrategy.relationName(this._name) : this._name;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "relatedEntityMetadata", {
        get: function () {
            return this._relatedEntityMetadata;
        },
        set: function (metadata) {
            this._relatedEntityMetadata = metadata;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "junctionEntityMetadata", {
        get: function () {
            return this._junctionEntityMetadata;
        },
        set: function (metadata) {
            this._junctionEntityMetadata = metadata;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "relationType", {
        get: function () {
            return this._relationType;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "type", {
        get: function () {
            return this._type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "inverseSideProperty", {
        get: function () {
            return this.computeInverseSide(this._inverseSideProperty);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "inverseRelation", {
        get: function () {
            return this._relatedEntityMetadata.findRelationWithPropertyName(this.computeInverseSide(this._inverseSideProperty));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOwning", {
        get: function () {
            return this._isOwning;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isCascadeInsert", {
        get: function () {
            return this._isCascadeInsert;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isCascadeUpdate", {
        get: function () {
            return this._isCascadeUpdate;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isCascadeRemove", {
        get: function () {
            return this._isCascadeRemove;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOneToOne", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.ONE_TO_ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOneToMany", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.ONE_TO_MANY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isManyToOne", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.MANY_TO_ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isManyToMany", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.MANY_TO_MANY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isNullable", {
        get: function () {
            return this._isNullable;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "oldColumnName", {
        get: function () {
            return this._oldColumnName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "onDelete", {
        get: function () {
            return this._onDelete;
        },
        enumerable: true,
        configurable: true
    });
    // ---------------------------------------------------------------------
    // Private Methods
    // ---------------------------------------------------------------------
    RelationMetadata.prototype.computeInverseSide = function (inverseSide) {
        var ownerEntityPropertiesMap = this.relatedEntityMetadata.createPropertiesMap();
        if (typeof inverseSide === "function")
            return inverseSide(ownerEntityPropertiesMap);
        if (typeof inverseSide === "string")
            return inverseSide;
        return null;
    };
    return RelationMetadata;
}(PropertyMetadata_1.PropertyMetadata));
exports.RelationMetadata = RelationMetadata;
//# sourceMappingURL=RelationMetadata.js.map