import { Connection } from "../connection/Connection";
import { PersistOperation } from "./operation/PersistOperation";
/**
 * Executes PersistOperation in the given connection.
 */
export declare class PersistOperationExecutor {
    private connection;
    constructor(connection: Connection);
    /**
     * Executes given persist operation.
     */
    executePersistOperation(persistOperation: PersistOperation): Promise<Promise<void>[]>;
    /**
     * Broadcast all before persistment events - beforeInsert, beforeUpdate and beforeRemove events.
     */
    private broadcastBeforeEvents(broadcaster, persistOperation);
    /**
     * Broadcast all after persistment events - afterInsert, afterUpdate and afterRemove events.
     */
    private broadcastAfterEvents(broadcaster, persistOperation);
    /**
     * Executes insert operations.
     */
    private executeInsertOperations(persistOperation);
    /**
     * Executes insert junction operations.
     */
    private executeInsertJunctionsOperations(persistOperation);
    /**
     * Executes remove junction operations.
     */
    private executeRemoveJunctionsOperations(persistOperation);
    /**
     * Executes update relations operations.
     */
    private executeUpdateRelationsOperations(persistOperation);
    /**
     * Executes update operations.
     */
    private executeUpdateOperations(persistOperation);
    /**
     * Executes remove relations operations.
     */
    private executeRemoveRelationOperations(persistOperation);
    /**
     * Executes remove operations.
     */
    private executeRemoveOperations(persistOperation);
    /**
     * Updates all ids of the inserted entities.
     */
    private updateIdsOfInsertedEntities(persistOperation);
    /**
     * Removes all ids of the removed entities.
     */
    private updateIdsOfRemovedEntities(persistOperation);
    private updateByRelation(operation, insertOperations);
    private update(updateOperation);
    private updateDeletedRelations(removeOperation);
    private delete(entity);
    private insert(entity);
    private insertJunctions(junctionOperation, insertOperations);
    private removeJunctions(junctionOperation);
    private zipObject(keys, values);
}
