import { Alias } from "./alias/Alias";
import { AliasMap } from "./alias/AliasMap";
import { Connection } from "../connection/Connection";
export interface Join {
    alias: Alias;
    type: "left" | "inner";
    conditionType: "on" | "with";
    condition: string;
}
export declare class QueryBuilder<Entity> {
    private connection;
    private broadcaster;
    private _aliasMap;
    private type;
    private selects;
    private fromEntity;
    private fromTableName;
    private fromTableAlias;
    private updateQuerySet;
    private joins;
    private groupBys;
    private wheres;
    private havings;
    private orderBys;
    private parameters;
    private limit;
    private offset;
    private firstResult;
    private maxResults;
    constructor(connection: Connection);
    aliasMap: AliasMap;
    delete(entity?: Function): this;
    delete(tableName?: string): this;
    update(updateSet: Object): this;
    update(entity: Function, updateSet: Object): this;
    update(tableName: string, updateSet: Object): this;
    select(selection?: string): this;
    select(selection?: string[]): this;
    select(...selection: string[]): this;
    addSelect(selection: string): this;
    addSelect(selection: string[]): this;
    addSelect(...selection: string[]): this;
    from(tableName: string, alias: string): this;
    from(entity: Function, alias: string): this;
    innerJoinAndSelect(property: string, alias: string, conditionType?: "on" | "with", condition?: string): this;
    innerJoinAndSelect(entity: Function, alias: string, conditionType?: "on" | "with", condition?: string): this;
    innerJoin(property: string, alias: string, conditionType?: "on" | "with", condition?: string): this;
    innerJoin(entity: Function, alias: string, conditionType?: "on" | "with", condition?: string): this;
    leftJoinAndSelect(property: string, alias: string, conditionType?: "on" | "with", condition?: string): this;
    leftJoinAndSelect(entity: Function, alias: string, conditionType?: "on" | "with", condition?: string): this;
    leftJoin(property: string, alias: string, conditionType?: "on" | "with", condition?: string): this;
    leftJoin(entity: Function, alias: string, conditionType?: "on" | "with", condition?: string): this;
    join(joinType: "inner" | "left", property: string, alias: string, conditionType?: "on" | "with", condition?: string): this;
    join(joinType: "inner" | "left", entity: Function, alias: string, conditionType?: "on" | "with", condition?: string): this;
    join(joinType: "inner" | "left", entityOrProperty: Function | string, alias: string, conditionType: "on" | "with", condition: string): this;
    where(where: string, parameters?: {
        [key: string]: any;
    }): this;
    andWhere(where: string, parameters?: {
        [key: string]: any;
    }): this;
    orWhere(where: string, parameters?: {
        [key: string]: any;
    }): this;
    groupBy(groupBy: string): this;
    addGroupBy(groupBy: string): this;
    having(having: string, parameters?: {
        [key: string]: any;
    }): this;
    andHaving(having: string, parameters?: {
        [key: string]: any;
    }): this;
    orHaving(having: string, parameters?: {
        [key: string]: any;
    }): this;
    orderBy(sort: string, order?: "ASC" | "DESC"): this;
    addOrderBy(sort: string, order?: "ASC" | "DESC"): this;
    setLimit(limit: number): this;
    setOffset(offset: number): this;
    setFirstResult(firstResult: number): this;
    setMaxResults(maxResults: number): this;
    setParameter(key: string, value: any): this;
    setParameters(parameters: {
        [key: string]: any;
    }): this;
    addParameters(parameters: {
        [key: string]: any;
    }): this;
    getSql(): string;
    execute(): Promise<any>;
    getScalarResults<T>(): Promise<T[]>;
    getSingleScalarResult<T>(): Promise<T>;
    getResults(): Promise<Entity[]>;
    getSingleResult(): Promise<Entity>;
    getCount(): Promise<number>;
    getResultsAndCount(): Promise<[Entity[], number]>;
    clone(options?: {
        skipOrderBys?: boolean;
    }): QueryBuilder<{}>;
    protected rawResultsToEntities(results: any[]): any[];
    protected createSelectExpression(): string;
    protected createWhereExpression(): string;
    protected createJoinExpression(): string;
    protected createGroupByExpression(): string;
    protected createHavingExpression(): string;
    protected createOrderByExpression(): string;
    protected createLimitExpression(): string;
    protected createOffsetExpression(): string;
    protected replaceParameters(sql: string): string;
}
