"use strict";
var AliasMap = (function () {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    function AliasMap(entityMetadatas) {
        this.entityMetadatas = entityMetadatas;
        // -------------------------------------------------------------------------
        // Properties
        // -------------------------------------------------------------------------
        this.aliases = [];
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    AliasMap.prototype.addMainAlias = function (alias) {
        var mainAlias = this.mainAlias;
        if (mainAlias)
            this.aliases.splice(this.aliases.indexOf(mainAlias), 1);
        alias.isMain = true;
        this.aliases.push(alias);
    };
    AliasMap.prototype.addAlias = function (alias) {
        this.aliases.push(alias);
    };
    Object.defineProperty(AliasMap.prototype, "mainAlias", {
        get: function () {
            return this.aliases.find(function (alias) { return alias.isMain; });
        },
        enumerable: true,
        configurable: true
    });
    AliasMap.prototype.findAliasByName = function (name) {
        return this.aliases.find(function (alias) { return alias.name === name; });
    };
    AliasMap.prototype.findAliasByParent = function (parentAliasName, parentPropertyName) {
        return this.aliases.find(function (alias) {
            return alias.parentAliasName === parentAliasName && alias.parentPropertyName === parentPropertyName;
        });
    };
    AliasMap.prototype.getEntityMetadataByAlias = function (alias) {
        if (alias.target) {
            return this.findMetadata(alias.target);
        }
        else if (alias.parentAliasName && alias.parentPropertyName) {
            var parentAlias = this.findAliasByName(alias.parentAliasName); // todo: throw exceptions everywhere
            var parentEntityMetadata = this.getEntityMetadataByAlias(parentAlias);
            var relation = parentEntityMetadata.findRelationWithDbName(alias.parentPropertyName);
            if (!relation)
                throw new Error("Relation metadata for " + alias.parentAliasName + "#" + alias.parentPropertyName + " was not found.");
            return relation.relatedEntityMetadata;
        }
        throw new Error("Cannot get entity metadata for the given alias " + alias.name);
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    AliasMap.prototype.findMetadata = function (target) {
        var metadata = this.entityMetadatas.find(function (metadata) { return metadata.target === target; });
        if (!metadata)
            throw new Error("Metadata for " + target.name + " was not found.");
        return metadata;
    };
    return AliasMap;
}());
exports.AliasMap = AliasMap;
//# sourceMappingURL=AliasMap.js.map