"use strict";
/**
 * Transforms plain old javascript object
 * Entity is constructed based on its entity metadata.
 */
var PlainObjectToDatabaseEntityTransformer = (function () {
    function PlainObjectToDatabaseEntityTransformer() {
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    PlainObjectToDatabaseEntityTransformer.prototype.transform = function (object, metadata, queryBuilder) {
        // if object does not have id then nothing to load really
        if (!metadata.hasPrimaryKey || !object[metadata.primaryColumn.name])
            return null;
        var alias = queryBuilder.aliasMap.mainAlias.name;
        var needToLoad = this.buildLoadMap(object, metadata, true);
        this.join(queryBuilder, needToLoad, alias);
        return queryBuilder
            .where(alias + "." + metadata.primaryColumn.name + "=:id")
            .setParameter("id", object[metadata.primaryColumn.name])
            .getSingleResult();
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    PlainObjectToDatabaseEntityTransformer.prototype.join = function (qb, needToLoad, parentAlias) {
        var _this = this;
        needToLoad.forEach(function (i) {
            var alias = parentAlias + "_" + i.name;
            qb.leftJoinAndSelect(parentAlias + "." + i.name, alias);
            if (i.child && i.child.length)
                _this.join(qb, i.child, alias);
        });
    };
    PlainObjectToDatabaseEntityTransformer.prototype.buildLoadMap = function (object, metadata, isFirstLevelDepth) {
        var _this = this;
        if (isFirstLevelDepth === void 0) { isFirstLevelDepth = false; }
        // todo: rething the way we are trying to load things using left joins cause there are situations when same
        // todo: entities are loaded multiple times and become different objects (problem with duplicate entities in dbEntities)
        return metadata.relations
            .filter(function (relation) { return object.hasOwnProperty(relation.propertyName); })
            .filter(function (relation) {
            // we only need to load empty relations for first-level depth objects, otherwise removal can break
            // this is not reliable, refactor this part later
            return isFirstLevelDepth || !(object[relation.propertyName] instanceof Array) || object[relation.propertyName].length > 0;
        })
            .map(function (relation) {
            var value = object[relation.propertyName];
            if (value instanceof Array)
                value = Object.assign.apply(Object, [{}].concat(value));
            var child = value ? _this.buildLoadMap(value, relation.relatedEntityMetadata) : [];
            return { name: relation.name, child: child };
        });
    };
    return PlainObjectToDatabaseEntityTransformer;
}());
exports.PlainObjectToDatabaseEntityTransformer = PlainObjectToDatabaseEntityTransformer;
//# sourceMappingURL=PlainObjectToDatabaseEntityTransformer.js.map