"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var SchemaBuilder_1 = require("./SchemaBuilder");
var ForeignKeyMetadata_1 = require("../metadata-builder/metadata/ForeignKeyMetadata");
var MysqlSchemaBuilder = (function (_super) {
    __extends(MysqlSchemaBuilder, _super);
    function MysqlSchemaBuilder(driver) {
        _super.call(this);
        this.driver = driver;
    }
    MysqlSchemaBuilder.prototype.getChangedColumns = function (tableName, columns) {
        var _this = this;
        var sql = ("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = '" + this.driver.db + "'") +
            (" AND TABLE_NAME = '" + tableName + "'");
        return this.query(sql).then(function (results) {
            return columns.filter(function (column) {
                var dbData = results.find(function (result) { return result.COLUMN_NAME === column.name; });
                if (!dbData)
                    return false;
                var newType = _this.normalizeType(column);
                var isNullable = column.isNullable === true ? "YES" : "NO";
                var hasDbColumnAutoIncrement = dbData.EXTRA.indexOf("auto_increment") !== -1;
                var hasDbColumnPrimaryIndex = dbData.COLUMN_KEY.indexOf("PRI") !== -1;
                return dbData.COLUMN_TYPE !== newType ||
                    dbData.COLUMN_COMMENT !== column.comment ||
                    dbData.IS_NULLABLE !== isNullable ||
                    hasDbColumnAutoIncrement !== column.isAutoIncrement ||
                    hasDbColumnPrimaryIndex !== column.isPrimary;
            }).map(function (column) {
                var dbData = results.find(function (result) { return result.COLUMN_NAME === column.name; });
                var hasDbColumnPrimaryIndex = dbData.COLUMN_KEY.indexOf("PRI") !== -1;
                return { columnName: column.name, hasPrimaryKey: hasDbColumnPrimaryIndex };
            });
        });
    };
    MysqlSchemaBuilder.prototype.checkIfTableExist = function (tableName) {
        var sql = "SELECT * FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_SCHEMA = '" + this.driver.db + "' AND TABLE_NAME = '" + tableName + "'";
        return this.query(sql).then(function (results) { return !!(results && results.length); });
    };
    MysqlSchemaBuilder.prototype.addColumnQuery = function (tableName, column) {
        var sql = "ALTER TABLE " + tableName + " ADD " + this.buildCreateColumnSql(column, false);
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.dropColumnQuery = function (tableName, columnName) {
        var sql = "ALTER TABLE " + tableName + " DROP " + columnName;
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.addForeignKeyQuery = function (foreignKey) {
        var sql = ("ALTER TABLE " + foreignKey.table.name + " ADD CONSTRAINT `" + foreignKey.name + "` ") +
            ("FOREIGN KEY (" + foreignKey.columnNames.join(", ") + ") ") +
            ("REFERENCES " + foreignKey.referencedTable.name + "(" + foreignKey.referencedColumnNames.join(",") + ")");
        if (foreignKey.onDelete)
            sql += " ON DELETE " + foreignKey.onDelete;
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.dropForeignKeyQuery = function (tableNameOrForeignKey, foreignKeyName) {
        var tableName = tableNameOrForeignKey;
        if (tableNameOrForeignKey instanceof ForeignKeyMetadata_1.ForeignKeyMetadata) {
            tableName = tableNameOrForeignKey.table.name;
            foreignKeyName = tableNameOrForeignKey.name;
        }
        var sql = "ALTER TABLE " + tableName + " DROP FOREIGN KEY `" + foreignKeyName + "`";
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.getTableForeignQuery = function (table) {
        var sql = ("SELECT * FROM INFORMATION_SCHEMA.KEY_COLUMN_USAGE WHERE TABLE_SCHEMA = \"" + this.driver.db + "\" ")
            + ("AND TABLE_NAME = \"" + table.name + "\" AND REFERENCED_COLUMN_NAME IS NOT NULL");
        return this.query(sql).then(function (results) { return results.map(function (result) { return result.CONSTRAINT_NAME; }); });
    };
    MysqlSchemaBuilder.prototype.getTableUniqueKeysQuery = function (tableName) {
        var sql = ("SELECT * FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_SCHEMA = \"" + this.driver.db + "\" ") +
            ("AND TABLE_NAME = \"" + tableName + "\" AND CONSTRAINT_TYPE = 'UNIQUE'");
        return this.query(sql).then(function (results) { return results.map(function (result) { return result.CONSTRAINT_NAME; }); });
    };
    MysqlSchemaBuilder.prototype.getPrimaryConstraintName = function (tableName) {
        var sql = ("SELECT * FROM INFORMATION_SCHEMA.TABLE_CONSTRAINTS WHERE TABLE_SCHEMA = \"" + this.driver.db + "\"")
            + (" AND TABLE_NAME = \"" + tableName + "\" AND CONSTRAINT_TYPE = 'PRIMARY KEY'");
        return this.query(sql).then(function (results) { return results && results.length ? results[0].CONSTRAINT_NAME : undefined; });
    };
    MysqlSchemaBuilder.prototype.dropIndex = function (tableName, indexName) {
        var sql = "ALTER TABLE " + tableName + " DROP INDEX `" + indexName + "`";
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.addUniqueKey = function (tableName, columnName, keyName) {
        var sql = "ALTER TABLE " + tableName + " ADD CONSTRAINT " + keyName + " UNIQUE (" + columnName + ")";
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.getTableColumns = function (tableName) {
        var sql = ("SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA = '" + this.driver.db + "'") +
            (" AND TABLE_NAME = '" + tableName + "'");
        return this.query(sql).then(function (results) { return results.map(function (result) { return result.COLUMN_NAME; }); });
    };
    MysqlSchemaBuilder.prototype.changeColumnQuery = function (tableName, columnName, newColumn, skipPrimary) {
        if (skipPrimary === void 0) { skipPrimary = false; }
        var sql = "ALTER TABLE " + tableName + " CHANGE " + columnName + " " + this.buildCreateColumnSql(newColumn, skipPrimary);
        return this.query(sql).then(function () { });
    };
    MysqlSchemaBuilder.prototype.createTableQuery = function (table, columns) {
        var _this = this;
        var columnDefinitions = columns.map(function (column) { return _this.buildCreateColumnSql(column, false); }).join(", ");
        var sql = "CREATE TABLE `" + table.name + "` (" + columnDefinitions + ") ENGINE=InnoDB;";
        return this.query(sql).then(function () { });
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    MysqlSchemaBuilder.prototype.query = function (sql) {
        return this.driver.query(sql);
    };
    MysqlSchemaBuilder.prototype.buildCreateColumnSql = function (column, skipPrimary) {
        var c = column.name + " " + this.normalizeType(column);
        if (column.isNullable !== true)
            c += " NOT NULL";
        if (column.isPrimary === true && !skipPrimary)
            c += " PRIMARY KEY";
        if (column.isAutoIncrement === true)
            c += " AUTO_INCREMENT";
        if (column.comment)
            c += " COMMENT '" + column.comment + "'";
        if (column.columnDefinition)
            c += " " + column.columnDefinition;
        return c;
    };
    MysqlSchemaBuilder.prototype.normalizeType = function (column) {
        var realType;
        if (typeof column.type === "string") {
            realType = column.type.toLowerCase();
        }
        else if (typeof column.type === "object" && column.type.name && typeof column.type.name === "string") {
            realType = column.type.toLowerCase();
        }
        switch (realType) {
            case "string":
                return "varchar(" + (column.length ? column.length : 255) + ")";
            case "text":
                return "text";
            case "boolean":
                return "boolean";
            case "integer":
            case "int":
                return "INT(" + (column.length ? column.length : 11) + ")";
            case "smallint":
                return "SMALLINT(" + (column.length ? column.length : 11) + ")";
            case "bigint":
                return "BIGINT(" + (column.length ? column.length : 11) + ")";
            case "float":
                return "FLOAT";
            case "double":
            case "number":
                return "DOUBLE";
            case "decimal":
                if (column.precision && column.scale) {
                    return "DECIMAL(" + column.precision + "," + column.scale + ")";
                }
                else if (column.scale) {
                    return "DECIMAL(" + column.scale + ")";
                }
                else if (column.precision) {
                    return "DECIMAL(" + column.precision + ")";
                }
                else {
                    return "DECIMAL";
                }
            case "date":
                return "DATE";
            case "time":
                return "TIME";
            case "datetime":
                return "DATETIME";
            case "json":
                return "text";
            case "simple_array":
                return column.length ? "varchar(" + column.length + ")" : "text";
        }
        throw new Error("Specified type (" + column.type + ") is not supported by current driver.");
    };
    return MysqlSchemaBuilder;
}(SchemaBuilder_1.SchemaBuilder));
exports.MysqlSchemaBuilder = MysqlSchemaBuilder;
//# sourceMappingURL=MysqlSchemaBuilder.js.map