import { Connection } from "../connection/Connection";
/**
 * Creates indexes based on the given metadata
 */
export declare class SchemaCreator {
    private connection;
    private schemaBuilder;
    constructor(connection: Connection);
    /**
     * Creates complete schemas for the given entity metadatas.
     */
    create(): Promise<void>;
    private dropForeignKeysForAll(metadatas);
    private createTablesForAll(metadatas);
    private updateOldColumnsForAll(metadatas);
    private dropRemovedColumnsForAll(metadatas);
    private addNewColumnsForAll(metadatas);
    private updateExistColumnsForAll(metadatas);
    private createForeignKeysForAll(metadatas);
    private updateUniqueKeysForAll(metadatas);
    private removePrimaryKeyForAll(metadatas);
    /**
     * Drops all (old) foreign keys that exist in the table, but does not exist in the metadata.
     */
    private dropForeignKeys(table, foreignKeys);
    /**
     * Creates a new table if it does not exist.
     */
    private createNewTable(table, columns);
    /**
     * Renames (and updates) all columns that has "oldColumnName".
     */
    private updateOldColumns(table, columns);
    /**
     * Drops all columns exist (left old) in the table, but does not exist in the metadata.
     */
    private dropRemovedColumns(table, columns);
    /**
     * Adds columns from metadata which does not exist in the table.
     */
    private addNewColumns(table, columns);
    /**
     * Update all exist columns which metadata has changed.
     */
    private updateExistColumns(table, columns);
    /**
     * Creates foreign keys which does not exist in the table yet.
     */
    private createForeignKeys(table, foreignKeys);
    /**
     * Creates unique keys which are missing in db yet, and drops unique keys which exist in the db,
     * but does not exist in the metadata anymore.
     */
    private updateUniqueKeys(table, columns);
    /**
     * Removes primary key from the table (if it was before and does not exist in the metadata anymore).
     */
    private removePrimaryKey(table);
}
