"use strict";
var ConnectionManager_1 = require("./connection/ConnectionManager");
var MysqlDriver_1 = require("./driver/MysqlDriver");
/**
 * Global connection manager.
 */
exports.connectionManager = new ConnectionManager_1.ConnectionManager();
/**
 * Creates a new connection with the database.
 */
function createConnection(options) {
    var connection;
    switch (options.driver) {
        case "mysql":
            connection = exports.connectionManager.createConnection(options.connectionName, new MysqlDriver_1.MysqlDriver(), options.connection);
            break;
        default:
            throw new Error("Wrong driver " + options.driver + " given. Supported drivers are: \"mysql\"");
    }
    if (options.entityDirectories && options.entityDirectories.length > 0)
        exports.connectionManager.importEntitiesFromDirectories(options.connectionName, options.entityDirectories);
    if (options.entities)
        exports.connectionManager.importEntities(options.connectionName, options.entities);
    if (options.subscriberDirectories && options.subscriberDirectories.length > 0)
        exports.connectionManager.importSubscribersFromDirectories(options.connectionName, options.subscriberDirectories);
    if (options.subscribers)
        exports.connectionManager.importSubscribers(options.subscribers);
    return connection.connect().then(function () { return connection; });
}
exports.createConnection = createConnection;
//# sourceMappingURL=typeorm.js.map